@@ -39,6 +39,7 @@ static void _eztrace_run_atexit_functions();
 static pthread_key_t protect_on;
 
 struct _ezt_write_trace _ezt_trace;
+int* _ezt_timestamp_config = &_ezt_trace.timestamp_config;
 __thread enum ezt_trace_status thread_status = ezt_trace_status_uninitialized;
 __thread uint64_t thread_rank=0;
 __thread uint64_t otf2_thread_id=0;
@@ -321,12 +322,30 @@ static void do_nothing(int signo MAYBE_UNUSED) {
 
 void  _init_modules() ;
 
-static void _set_debug_mode() {
+static void _eztrace_load_config() {
   static int done = 0;
   if(done) return;
-
   done=1;
 
+  _ezt_timestamp_config = &_ezt_trace.timestamp_config;
+  _ezt_trace.timestamp_config = TS_SOURCE_CLOCK_MONOTONIC | TS_RELATIVE;
+
+  char* ts_src = getenv("EZTRACE_TIMESTAMP_SOURCE");
+  if (ts_src) {
+    if(strcmp(ts_src, "rdtsc") == 0) {
+      _ezt_trace.timestamp_config ^= TS_SOURCE_CLOCK_MONOTONIC;
+      _ezt_trace.timestamp_config |= TS_SOURCE_RDTSC;
+    }
+  }
+
+  char* ts_config = getenv("EZTRACE_TIMESTAMP_CONFIG");
+  if (ts_config) {
+    if(strcmp(ts_config, "absolute") == 0) {
+      _ezt_trace.timestamp_config ^= TS_RELATIVE;
+      _ezt_trace.timestamp_config |= TS_ABSOLUTE;
+    }
+  }
+
   _ezt_trace.debug_level = dbg_lvl_normal;
   char* debug_mode = getenv("EZTRACE_DEBUG");
   if (debug_mode) {
@@ -334,7 +353,7 @@ static void _set_debug_mode() {
     if(dbg_lvl > dbg_lvl_max) dbg_lvl = dbg_lvl_max;
     _ezt_trace.debug_level = dbg_lvl;
     eztrace_log(dbg_lvl_normal, "EZTrace Debug mode enabled (trace level: %d)\n",
-               _ezt_trace.debug_level);
+		_ezt_trace.debug_level);
   }
 }
 
@@ -363,7 +382,7 @@ void _eztrace_init() {
   if(!using_mpi)
     _ezt_trace.status = ezt_trace_status_uninitialized;
 
-  _set_debug_mode();
+  _eztrace_load_config();
   
   eztrace_log(dbg_lvl_normal, "Starting EZTrace (pid: %d)...\n", getpid());
   if(using_mpi) {
@@ -397,7 +416,7 @@ int ezt_is_mpi_mode() {
 extern struct ezt_internal_module* ezt_otf2_module;
 void eztrace_core_constructor() __attribute__((constructor));
 void eztrace_core_constructor() {
-  _set_debug_mode();
+  _eztrace_load_config();
   char cmd[1024];
   _get_current_program_name(cmd);
 
